@@ -385,11 +385,11 @@ class BoardsController(rest.RestController):
         event_owners = [{id: users_api.user_get(id).full_name}
                         for id in owners]
         event_team_owners = [{id: teams_api.team_get(id).name}
-                             for id in owners]
+                             for id in team_owners]
         event_users = [{id: users_api.user_get(id).full_name}
                        for id in users]
         event_team_users = [{id: teams_api.team_get(id).name}
-                            for id in users]
+                            for id in team_users]
         events_api.board_permission_created_event(created_board.id,
                                                   user_id,
                                                   edit.id,
