@@ -28,6 +28,7 @@ import wsmeext.pecan as wsme_pecan
 
 from storyboard._i18n import _
 from storyboard.api.auth import authorization_checks as checks
+from storyboard.api.v1.attachments import AttachmentsController
 from storyboard.api.v1.search import search_engine
 from storyboard.api.v1.tags import TagsController
 from storyboard.api.v1.tasks import TasksNestedController
@@ -489,6 +490,8 @@ class StoriesController(rest.RestController):
         stories_api.story_delete(
             story_id, current_user=request.current_user_id)
 
+    if CONF.attachments.enable_attachments:
+        attachments = AttachmentsController()
     comments = CommentsController()
     events = NestedTimeLineEventsController()
     tasks = TasksNestedController()
