@@ -1,4 +1,5 @@
 # Copyright (c) 2013 Hewlett-Packard Development Company, L.P.
+# Copyright (c) 2019 Codethink Ltd.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -41,5 +42,13 @@ class SystemInfoController(rest.RestController):
 
         """
         sb_ver = VersionInfo('storyboard-api')
+        config = {
+            'enable_attachments': CONF.attachments.enable_attachments,
+            'enable_editable_comments': CONF.enable_editable_comments,
+            'enable_notifications': CONF.enable_notifications
+        }
 
-        return wmodels.SystemInfo(version=sb_ver.version_string())
+        return wmodels.SystemInfo(
+            config=config,
+            version=sb_ver.version_string()
+        )
