@@ -16,6 +16,8 @@
 import datetime
 import pytz
 
+from oslo_db import api as oslo_db_api
+
 from sqlalchemy.orm import subqueryload
 from wsme.exc import ClientSideError
 
@@ -275,6 +277,8 @@ def get_project_ids(story_id, current_user=None):
     return project_ids
 
 
+@oslo_db_api.wrap_db_retry(max_retries=3, retry_on_deadlock=True,
+retry_interval=0.5, inc_retry_interval=True)
 def story_update_updated_at(story_id):
     session = api_base.get_session()
     with session.begin(subtransactions=True):
