@@ -1,6 +1,7 @@
 # Copyright 2013 Hewlett-Packard Development Company, L.P.
 # Copyright 2013 Thierry Carrez <thierry@openstack.org>
 # Copyright 2015-2016 Codethink Ltd.
+# Copyright 2019 Adam Coldrick
 #
 # Licensed under the Apache License, Version 2.0 (the "License"); you may
 # not use this file except in compliance with the License. You may obtain
@@ -360,6 +361,20 @@ class Task(FullText, ModelBuilder, Base):
                       "milestone_id"]
 
 
+class Attachment(FullText, ModelBuilder, Base):
+    __tablename__ = 'attachments'
+    __fulltext_columns__ = ['name']
+
+    name = Column(Unicode(CommonLength.top_large_length), nullable=False)
+    link = Column(UnicodeText(), nullable=False)
+    creator_id = Column(
+        Integer, ForeignKey('users.id'), nullable=False, index=True)
+    story_id = Column(
+        Integer, ForeignKey('stories.id'), nullable=False, index=True)
+
+    _public_fields = ["id", "name", "link", "creator_id", "story_id"]
+
+
 story_permissions = Table(
     'story_permissions', Base.metadata,
     Column('story_id', Integer, ForeignKey('stories.id')),
